searchData={"content_type":"text/markdown","items":[{"doc":"Use this module in any module that uses `Ecto.Repo`\nto enrich it with `cursor_based_stream/2` function.\n\nExample:\n\n    defmodule MyRepo do\n      use Ecto.Repo\n      use EctoCursorBasedStream\n    end\n\n    MyUser\n    |> MyRepo.cursor_based_stream(max_rows: 100)\n    |> Stream.each(...)\n    |> Stream.run()","ref":"EctoCursorBasedStream.html","title":"EctoCursorBasedStream","type":"behaviour"},{"doc":"Return a lazy enumerable that emits all entries from the data store\nmatching the given query.\n\nIn contrast to `Ecto.Repo.stream/2`,\nthis will not use database mechanisms (e.g. database transactions) to stream the rows.\n\nIt does so by sorting all the rows by `options[:cursor_field]`\nand iterating over them in chunks of size `options[:max_rows]`.","ref":"EctoCursorBasedStream.html#c:cursor_based_stream/2","title":"EctoCursorBasedStream.cursor_based_stream/2","type":"callback"},{"doc":"* `:cursor_field` - the field by which all rows should be iterated.\n\n  **This field must have unique values. (Otherwise, some rows may get skipped.)**\n\n  For performance reasons, we recommend that you have an index on that field. Defaults to `:id`.\n\n* `:after_cursor` - the value of the `:cursor_field` must be greater than it.\n\n  Useful when you want to continue streaming from a certain point.\n  Any rows with value equal or smaller than this value will not be included.\n\n  Defaults to `nil`. (All rows will be included.)\n\n* `:max_rows` - The number of rows to load from the database as we stream.\n\n  Defaults to 500.","ref":"EctoCursorBasedStream.html#c:cursor_based_stream/2-options","title":"Options - EctoCursorBasedStream.cursor_based_stream/2","type":"callback"},{"doc":"MyUser\n    |> MyRepo.cursor_based_stream(max_rows: 100)\n    |> Stream.each(...)\n    |> Stream.run()","ref":"EctoCursorBasedStream.html#c:cursor_based_stream/2-example","title":"Example - EctoCursorBasedStream.cursor_based_stream/2","type":"callback"},{"doc":"","ref":"EctoCursorBasedStream.html#t:cursor_based_stream_opts/0","title":"EctoCursorBasedStream.cursor_based_stream_opts/0","type":"type"},{"doc":"# EctoCursorBasedStream\n\n![Build Status](https://img.shields.io/github/actions/workflow/status/allegro/ecto-cursor-based-stream/test.yml) [![Hex.pm](https://img.shields.io/hexpm/v/ecto_cursor_based_stream.svg)](https://hex.pm/packages/ecto_cursor_based_stream) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/ecto_cursor_based_stream/)\n\nCursor-based streaming of Ecto records, that does not require database transaction.\n\nGives you a [`cursor_based_stream/2`](https://hexdocs.pm/ecto_cursor_based_stream/EctoCursorBasedStream.html#c:cursor_based_stream/2) function that mimics [`Ecto.Repo.stream/2`](https://hexdocs.pm/ecto/Ecto.Repo.html#c:stream/2) interface.\n\nAdvantages in comparison to the standard `Ecto.Repo.stream/2`:\n\n- streaming can be stopped and continued at any point (by passing `opts[:after_cursor]`),\n- works with tables that have milions of records.\n\nOnly limitation is that you have to supply a _cursor column_ (by passing `opts[:cursor_field]`, defaults to `:id`). Such a column:\n\n- must have unique values,\n- should have a database index. (So that sorting by it, and returning a number of rows larger than `x` is a performant operation.)","ref":"readme.html","title":"EctoCursorBasedStream","type":"extras"},{"doc":"1. Add `ecto_cursor_based_stream` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_cursor_based_stream, \"~> 1.0.2\"}\n  ]\nend\n```\n\n2. Add `use EctoCursorBasedStream` to the module that uses `Ecto.Repo`:\n\n```elixir\ndefmodule MyRepo do\n  use Ecto.Repo\n  use EctoCursorBasedStream\nend\n```\n\n3. Stream the rows using `cursor_based_stream/2`:\n\n```elixir\nPost\n|> MyRepo.cursor_based_stream(max_rows: 100)\n|> Stream.each(...)\n|> Stream.run()\n```","ref":"readme.html#usage","title":"Usage - EctoCursorBasedStream","type":"extras"},{"doc":"- [Documentation](https://hexdocs.pm/ecto_cursor_based_stream)\n- [Examples](https://github.com/allegro/ecto-cursor-based-stream/blob/main/test/ecto_cursor_based_stream_test.exs)","ref":"readme.html#useful-links","title":"Useful links - EctoCursorBasedStream","type":"extras"},{"doc":"","ref":"readme.html#contributing","title":"Contributing - EctoCursorBasedStream","type":"extras"},{"doc":"Run the following after cloning the repo:\n\n```sh\nmix deps.get\ndocker-compose up -d\nmix test\n```","ref":"readme.html#running-tests","title":"Running tests - EctoCursorBasedStream","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}